/**
 *    Copyright (C) 2022 Graham Leggett <minfrin@sharp.fm>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/*
 * redwax_libical - libical routines for generating calendars
 *
 */

#ifndef REDWAX_LIBICAL_H_
#define REDWAX_LIBICAL_H_

#include "config.h"

#if HAVE_LIBICAL_ICAL_H

void redwax_add_default_libical_hooks(apr_pool_t *pool);

#endif
#endif /* REDWAX_LIBICAL_H_ */
